==> ejc-probuilddiary-impl-3.0.0-20221208.093219-103-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonScheduleEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-进度情况（施工员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_schedule")
public class PersonScheduleEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="schedule_memo")
    private String scheduleMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public String getScheduleMemo() {
        return scheduleMemo;
    }

    public void setScheduleMemo(String scheduleMemo) {
        this.scheduleMemo = scheduleMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20250327.054615-148-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonScheduleEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-进度情况（施工员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_schedule")
public class PersonScheduleEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="schedule_memo")
    private String scheduleMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public String getScheduleMemo() {
        return scheduleMemo;
    }

    public void setScheduleMemo(String scheduleMemo) {
        this.scheduleMemo = scheduleMemo;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}
